package Sah::Schema::ufloat;

our $DATE = '2019-04-08'; # DATE
our $VERSION = '0.003'; # VERSION

our $schema = [float => {
    summary   => 'Non-negative float',
    min       => 0,
   description => <<'_',

See also `posfloat` for floats that are larger than 0.

_
 }, {}];

1;
# ABSTRACT: Non-negative float

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schema::ufloat - Non-negative float

=head1 VERSION

This document describes version 0.003 of Sah::Schema::ufloat (from Perl distribution Sah-Schemas-Float), released on 2019-04-08.

=head1 DESCRIPTION

See also C<posfloat> for floats that are larger than 0.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Float>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Float>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Float>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
